@@ -151,6 +151,11 @@ enum {
 	PROP_RO
 };
 
+enum {
+	TRACKER_DB_CURSOR_PROP_0,
+	TRACKER_DB_CURSOR_PROP_N_COLUMNS
+};
+
 G_DEFINE_TYPE_WITH_CODE (TrackerDBInterface, tracker_db_interface, G_TYPE_OBJECT,
                          G_IMPLEMENT_INTERFACE (G_TYPE_INITABLE,
                                                 tracker_db_interface_initable_iface_init));
@@ -1593,6 +1598,22 @@ tracker_db_cursor_finalize (GObject *object)
 	G_OBJECT_CLASS (tracker_db_cursor_parent_class)->finalize (object);
 }
 
+static void
+tracker_db_cursor_get_property (GObject    *object,
+                                guint       prop_id,
+                                GValue     *value,
+                                GParamSpec *pspec)
+{
+	TrackerDBCursor *cursor = TRACKER_DB_CURSOR (object);
+	switch (prop_id) {
+	case TRACKER_DB_CURSOR_PROP_N_COLUMNS:
+		g_value_set_int (value, tracker_db_cursor_get_n_columns (cursor));
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+	}
+}
+
 static void
 tracker_db_cursor_iter_next_thread (GSimpleAsyncResult *res,
                                     GObject            *object,
@@ -1643,6 +1664,7 @@ tracker_db_cursor_class_init (TrackerDBCursorClass *class)
 	TrackerSparqlCursorClass *sparql_cursor_class = TRACKER_SPARQL_CURSOR_CLASS (class);
 
 	object_class->finalize = tracker_db_cursor_finalize;
+	object_class->get_property = tracker_db_cursor_get_property;
 
 	sparql_cursor_class->get_value_type = (TrackerSparqlValueType (*) (TrackerSparqlCursor *, gint)) tracker_db_cursor_get_value_type;
 	sparql_cursor_class->get_variable_name = (const gchar * (*) (TrackerSparqlCursor *, gint)) tracker_db_cursor_get_variable_name;
@@ -1656,6 +1678,8 @@ tracker_db_cursor_class_init (TrackerDBCursorClass *class)
 	sparql_cursor_class->get_integer = (gint64 (*) (TrackerSparqlCursor *, gint)) tracker_db_cursor_get_int;
 	sparql_cursor_class->get_double = (gdouble (*) (TrackerSparqlCursor *, gint)) tracker_db_cursor_get_double;
 	sparql_cursor_class->get_boolean = (gboolean (*) (TrackerSparqlCursor *, gint)) tracker_db_cursor_get_boolean;
+
+	g_object_class_override_property (object_class, TRACKER_DB_CURSOR_PROP_N_COLUMNS, "n-columns");
 }
 
 static TrackerDBCursor *
